@@ -576,7 +576,7 @@ L2UNIT_ntv_enum_events( unsigned int *EventCode, int modifier )
  *
  */
 int
-L2UNIT_ntv_name_to_code( char *name, unsigned int *event_code )
+L2UNIT_ntv_name_to_code( const char *name, unsigned int *event_code )
 {
 #ifdef DEBUG_BGQ
 	printf( "L2UNIT_ntv_name_to_code\n" );
