@@ -14,9 +14,20 @@
    - Get us.
 */
 
-#include "papi_test.h"
-#include <sys/ptrace.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
+
 #include <limits.h>
+#include <sys/ptrace.h>
+#include <sys/wait.h>
+
+#include "papi.h"
+#include "papi_test.h"
+
+#include "do_loops.h"
+
 
 #ifdef _AIX
 #define _LINUX_SOURCE_COMPAT
@@ -27,18 +38,18 @@
 # define PTRACE_TRACEME PT_TRACE_ME
 #endif
 
-int
+static int
 wait_for_attach_and_loop( void )
 {
   char *path;
   char newpath[PATH_MAX];
   path = getenv("PATH");
 
-  sprintf(newpath, "PATH=./:%s", (path)?path:'\0' );
+  sprintf(newpath, "PATH=./:%s", (path)?path:"\0" );
   putenv(newpath);
 
   if (ptrace(PTRACE_TRACEME, 0, 0, 0) == 0) {
-    execlp("attach_target","attach_target","100000000",NULL); 
+    execlp("attach_target","attach_target","100000000",NULL);
     perror("execl(attach_target) failed");
   }
   perror("PTRACE_TRACEME");
@@ -48,7 +59,7 @@ wait_for_attach_and_loop( void )
 int
 main( int argc, char **argv )
 {
-	int status, retval, num_tests = 1, tmp;
+	int status, retval, tmp;
 	int EventSet1 = PAPI_NULL;
 	long long **values;
 	long long elapsed_us, elapsed_cyc, elapsed_virt_us, elapsed_virt_cyc;
@@ -56,6 +67,7 @@ main( int argc, char **argv )
 	const PAPI_hw_info_t *hw_info;
 	const PAPI_component_info_t *cmpinfo;
 	pid_t pid;
+	int quiet;
 
 	/* Fork before doing anything with the PMU */
 
@@ -66,17 +78,18 @@ main( int argc, char **argv )
 	if ( pid == 0 )
 		exit( wait_for_attach_and_loop(  ) );
 
-	tests_quiet( argc, argv );	/* Set TESTS_QUIET variable */
+	/* Set TESTS_QUIET variable */
+	quiet=tests_quiet( argc, argv );
 
 
 	/* Master only process below here */
 
 	retval = PAPI_library_init( PAPI_VER_CURRENT );
 	if ( retval != PAPI_VER_CURRENT )
-		test_fail_exit( __FILE__, __LINE__, "PAPI_library_init", retval );
+		test_fail( __FILE__, __LINE__, "PAPI_library_init", retval );
 
 	if ( ( cmpinfo = PAPI_get_component_info( 0 ) ) == NULL )
-		test_fail_exit( __FILE__, __LINE__, "PAPI_get_component_info", 0 );
+		test_fail( __FILE__, __LINE__, "PAPI_get_component_info", 0 );
 
 	if ( cmpinfo->attach == 0 )
 		test_skip( __FILE__, __LINE__, "Platform does not support attaching",
@@ -84,14 +97,14 @@ main( int argc, char **argv )
 
 	hw_info = PAPI_get_hardware_info(  );
 	if ( hw_info == NULL )
-		test_fail_exit( __FILE__, __LINE__, "PAPI_get_hardware_info", 0 );
+		test_fail( __FILE__, __LINE__, "PAPI_get_hardware_info", 0 );
 
 	/* add PAPI_TOT_CYC and one of the events in PAPI_FP_INS, PAPI_FP_OPS or
 	   PAPI_TOT_INS, depending on the availability of the event on the
 	   platform */
 	retval = PAPI_create_eventset(&EventSet1);
 	if ( retval != PAPI_OK )
-		test_fail_exit( __FILE__, __LINE__, "PAPI_attach", retval );
+		test_fail( __FILE__, __LINE__, "PAPI_attach", retval );
 
 	/* Force addition of component */
 
@@ -104,14 +117,15 @@ main( int argc, char **argv )
 
 	retval = PAPI_attach( EventSet1, ( unsigned long ) pid );
 	if ( retval != PAPI_OK )
-		test_fail_exit( __FILE__, __LINE__, "PAPI_attach", retval );
+		test_fail( __FILE__, __LINE__, "PAPI_attach", retval );
 
 
 
 	retval = PAPI_add_event(EventSet1, PAPI_TOT_CYC);
-	if ( retval != PAPI_OK )
-		test_fail_exit( __FILE__, __LINE__, "PAPI_add_event", retval );
-
+	if ( retval != PAPI_OK ) {
+		if (!quiet) printf("Could not add PAPI_TOT_CYC\n");
+		test_skip( __FILE__, __LINE__, "PAPI_add_event", retval );
+	}
 
 	strcpy(event_name,"PAPI_FP_INS");
 	retval = PAPI_add_named_event(EventSet1, event_name);
@@ -121,7 +135,7 @@ main( int argc, char **argv )
 	}
 
 	if ( retval != PAPI_OK ) {
-		test_fail_exit( __FILE__, __LINE__, "PAPI_add_event", retval );
+		test_fail( __FILE__, __LINE__, "PAPI_add_event", retval );
 	}
 
 	values = allocate_test_space( 1, 2);
@@ -134,27 +148,27 @@ main( int argc, char **argv )
 
 	elapsed_virt_cyc = PAPI_get_virt_cyc(  );
 
-	printf("must_ptrace is %d\n",cmpinfo->attach_must_ptrace);
+	if (!quiet) printf("must_ptrace is %d\n",cmpinfo->attach_must_ptrace);
 	pid_t  child = wait( &status );
-	printf( "Debugger exited wait() with %d\n",child );
+	if (!quiet) printf( "Debugger exited wait() with %d\n",child );
 	  if (WIFSTOPPED( status ))
 	    {
-	      printf( "Child has stopped due to signal %d (%s)\n",
+	      if (!quiet) printf( "Child has stopped due to signal %d (%s)\n",
 		      WSTOPSIG( status ), strsignal(WSTOPSIG( status )) );
 	    }
 	  if (WIFSIGNALED( status ))
 	    {
-	      printf( "Child %ld received signal %d (%s)\n",
+	      if (!quiet) printf( "Child %ld received signal %d (%s)\n",
 		      (long)child,
 		      WTERMSIG(status) , strsignal(WTERMSIG( status )) );
 	    }
-	printf("After %d\n",retval);
+	if (!quiet) printf("After %d\n",retval);
 
 	retval = PAPI_start( EventSet1 );
 	if ( retval != PAPI_OK )
-		test_fail_exit( __FILE__, __LINE__, "PAPI_start", retval );
+		test_fail( __FILE__, __LINE__, "PAPI_start", retval );
 
-	printf("Continuing\n");
+	if (!quiet) printf("Continuing\n");
 #if defined(__FreeBSD__)
 	if ( ptrace( PT_CONTINUE, pid, (caddr_t) 1, 0 ) == -1 ) {
 #else
@@ -167,27 +181,27 @@ main( int argc, char **argv )
 
 	do {
 	  child = wait( &status );
-	  printf( "Debugger exited wait() with %d\n", child);
+	  if (!quiet) printf( "Debugger exited wait() with %d\n", child);
 	  if (WIFSTOPPED( status ))
 	    {
-	      printf( "Child has stopped due to signal %d (%s)\n",
+	      if (!quiet) printf( "Child has stopped due to signal %d (%s)\n",
 		      WSTOPSIG( status ), strsignal(WSTOPSIG( status )) );
 	    }
 	  if (WIFSIGNALED( status ))
 	    {
-	      printf( "Child %ld received signal %d (%s)\n",
+	      if (!quiet) printf( "Child %ld received signal %d (%s)\n",
 		      (long)child,
 		      WTERMSIG(status) , strsignal(WTERMSIG( status )) );
 	    }
 	} while (!WIFEXITED( status ));
 
-	printf("Child exited with value %d\n",WEXITSTATUS(status));
-	if (WEXITSTATUS(status) != 0) 
-	  test_fail_exit( __FILE__, __LINE__, "Exit status of child to attach to", PAPI_EMISC);
-
+	if (!quiet) printf("Child exited with value %d\n",WEXITSTATUS(status));
+	if (WEXITSTATUS(status) != 0) {
+	  test_fail( __FILE__, __LINE__, "Exit status of child to attach to", PAPI_EMISC);
+	}
 	retval = PAPI_stop( EventSet1, values[0] );
 	if ( retval != PAPI_OK )
-	  test_fail_exit( __FILE__, __LINE__, "PAPI_stop", retval );
+	  test_fail( __FILE__, __LINE__, "PAPI_stop", retval );
 
 	elapsed_virt_us = PAPI_get_virt_usec(  ) - elapsed_virt_us;
 
@@ -199,12 +213,13 @@ main( int argc, char **argv )
 
 	retval = PAPI_cleanup_eventset(EventSet1);
 	if (retval != PAPI_OK)
-	  test_fail_exit( __FILE__, __LINE__, "PAPI_cleanup_eventset", retval );
+	  test_fail( __FILE__, __LINE__, "PAPI_cleanup_eventset", retval );
 
 	retval = PAPI_destroy_eventset(&EventSet1);
 	if (retval != PAPI_OK)
-	  test_fail_exit( __FILE__, __LINE__, "PAPI_destroy_eventset", retval );
+	  test_fail( __FILE__, __LINE__, "PAPI_destroy_eventset", retval );
 
+	if (!quiet) {
 	printf( "Test case: 3rd party attach start, stop.\n" );
 	printf( "-----------------------------------------------\n" );
 	tmp = PAPI_get_opt( PAPI_DEFDOM, NULL );
@@ -213,8 +228,7 @@ main( int argc, char **argv )
 	printf( "Default granularity is: %d (%s)\n", tmp,
 			stringify_granularity( tmp ) );
 	printf( "Using %d iterations of c += a*b\n", NUM_FLOPS );
-	printf
-		( "-------------------------------------------------------------------------\n" );
+	printf( "-------------------------------------------------------------------------\n" );
 
 	printf( "Test type    : \t           1\n" );
 
@@ -225,11 +239,12 @@ main( int argc, char **argv )
 	printf( TAB1, "Virt usec    : \t", elapsed_virt_us );
 	printf( TAB1, "Virt cycles  : \t", elapsed_virt_cyc );
 
-	printf
-		( "-------------------------------------------------------------------------\n" );
+	printf( "-------------------------------------------------------------------------\n" );
 
 	printf( "Verification: none\n" );
+	}
+	test_pass( __FILE__ );
+
+	return 0;
 
-	test_pass( __FILE__, values, num_tests );
-	exit( 1 );
 }
