@@ -1,4 +1,4 @@
-/* 
+/*
 * File:    data_range.c
 * Author:  Dan Terpstra
 *          terpstra@cs.utk.edu
@@ -9,7 +9,13 @@
 /* This file performs the following test: */
 /*     exercise the Itanium data address range interface */
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#include "papi.h"
 #include "papi_test.h"
+
 #define NUM 16384
 
 static void init_array( void );
@@ -30,7 +36,7 @@ main( int argc, char **argv )
 	int retval;
 	const PAPI_exe_info_t *prginfo = NULL;
 	const PAPI_hw_info_t *hw_info;
-	  
+
 	/* Set TESTS_QUIET variable */
 	tests_quiet( argc, argv );
 
@@ -123,9 +129,10 @@ main( int argc, char **argv )
 	free( parray2 );
 	free( parray3 );
 
-	test_pass( __FILE__, NULL, 0 );
+	test_pass( __FILE__ );
+
+	return 0;
 
-	exit( 1 );
 }
 
 static void
