@@ -1,5 +1,8 @@
+#include <stdio.h>
+#include <stdlib.h>
+
+#include "papi.h"
 #include "papi_test.h"
-extern int TESTS_QUIET;				   /* Declared in test_utils.c */
 
 int
 main( int argc, char **argv )
@@ -26,6 +29,8 @@ main( int argc, char **argv )
 		test_fail( __FILE__, __LINE__,
 				   "*preset returned did not equal PAPI_TOT_CYC", retval );
 
-	test_pass( __FILE__, NULL, 0 );
-	exit( 1 );
+	test_pass( __FILE__ );
+
+	return 0;
+
 }
