@@ -1,4 +1,4 @@
-/* 
+/*
 * File:    overflow_one_and_read.c : based on overflow_twoevents.c
 * Mods:    Philip Mucci
 *          mucci@cs.utk.edu
@@ -10,8 +10,14 @@
  * In the handler read events.
 */
 
+#include <stdio.h>
+#include <stdlib.h>
+
+#include "papi.h"
 #include "papi_test.h"
 
+#include "do_loops.h"
+
 #define OVER_FMT	"handler(%d) Overflow at %p! vector=%#llx\n"
 #define OUT_FMT		"%-12s : %16lld%16lld\n"
 
@@ -21,7 +27,7 @@ typedef struct
 	int count;
 } ocount_t;
 
-/* there are three possible vectors, one counter overflows, the other 
+/* there are three possible vectors, one counter overflows, the other
    counter overflows, both overflow */
 /*not used*/ ocount_t overflow_counts[3] = { {0, 0}, {0, 0}, {0, 0} };
 /*not used*/ int total_unknown = 0;
@@ -59,19 +65,26 @@ main( int argc, char **argv )
 	int PAPI_event;
 	char event_name[PAPI_MAX_STR_LEN];
 	int num_events1, mask1;
+	int quiet;
 
-	tests_quiet( argc, argv );	/* Set TESTS_QUIET variable */
+	/* Set TESTS_QUIET variable */
+	quiet=tests_quiet( argc, argv );
 
 	retval = PAPI_library_init( PAPI_VER_CURRENT );
-	if ( retval != PAPI_VER_CURRENT )
+	if ( retval != PAPI_VER_CURRENT ) {
 		test_fail( __FILE__, __LINE__, "PAPI_library_init", retval );
+	}
 
 	/* add PAPI_TOT_CYC and one of the events in PAPI_FP_INS, PAPI_FP_OPS or
 	   PAPI_TOT_INS, depends on the availability of the event on the
 	   platform */
 /* NOTE: Only adding one overflow on PAPI_event -- no overflow for PAPI_TOT_CYC*/
-	EventSet =
-		add_two_nonderived_events( &num_events1, &PAPI_event, &mask1 );
+	EventSet = add_two_nonderived_events( &num_events1,
+						&PAPI_event, &mask1 );
+	if (num_events1==0) {
+		if (!quiet) printf("Trouble adding events\n");
+		test_skip(__FILE__,__LINE__,"Adding event",1);
+	}
 
 	values = allocate_test_space( 2, num_events1 );
 
@@ -120,6 +133,7 @@ main( int argc, char **argv )
 		printf( OUT_FMT, "PAPI_TOT_CYC", ( values[0] )[1], ( values[1] )[1] );
 	}
 
-	test_pass( __FILE__, NULL, 0 );
-	exit( 1 );
+	test_pass( __FILE__ );
+
+	return 0;
 }
