@@ -36,6 +36,7 @@
 #define PERF_ATTR_MG	7	/* monitor guest execution */
 #define PERF_ATTR_MH	8	/* monitor host execution */
 #define PERF_ATTR_CPU	9	/* CPU to program */
+#define PERF_ATTR_PIN  10	/* pin event to CPU */
 
 #define _PERF_ATTR_U  (1 << PERF_ATTR_U)
 #define _PERF_ATTR_K  (1 << PERF_ATTR_K)
@@ -47,6 +48,7 @@
 #define _PERF_ATTR_MG (1 << PERF_ATTR_MG)
 #define _PERF_ATTR_MH (1 << PERF_ATTR_MH)
 #define _PERF_ATTR_CPU (1 << PERF_ATTR_CPU)
+#define _PERF_ATTR_PIN (1 << PERF_ATTR_PIN)
 
 #define PERF_PLM_ALL (PFM_PLM0|PFM_PLM3|PFM_PLMH)
 
