@@ -2,7 +2,7 @@
 /* THIS IS OPEN SOURCE CODE */
 /****************************/
 
-/* 
+/*
 * File:    papi_internal.c
 *
 * Author:  Philip Mucci
@@ -292,9 +292,9 @@ _papi_hwi_prefix_component_name( char *component_name, char *event_name, char *o
  *  This function checks specifically for ':::' and will return the start of 
  *  event_name if it doesn't find the ::: .
  */
-char *_papi_hwi_strip_component_prefix(char *event_name)
+const char *_papi_hwi_strip_component_prefix(const char *event_name)
 {
-	char *start = NULL;
+	const char *start = NULL;
 /* We assume ::: is the seperator 
  * eg: 
  * 		papi_component:::event_name 
@@ -354,7 +354,7 @@ _papi_hwi_add_native_event(int cidx, int ntv_event, int ntv_idx, const char *eve
 
   if (num_native_events>=num_native_chunks*NATIVE_EVENT_CHUNKSIZE) {
      num_native_chunks++;
-     _papi_native_events=realloc(_papi_native_events,
+     _papi_native_events=(struct native_event_info *) realloc(_papi_native_events,
 				 num_native_chunks*NATIVE_EVENT_CHUNKSIZE*
 				 sizeof(struct native_event_info));
      if (_papi_native_events==NULL) {
@@ -397,7 +397,7 @@ _papi_hwi_add_error( char *error )
 
 	if (_papi_hwi_num_errors >= num_error_chunks*NATIVE_EVENT_CHUNKSIZE) {
 		num_error_chunks++;
-		_papi_errlist=realloc(_papi_errlist, 
+		_papi_errlist= (char **) realloc(_papi_errlist, 
 						num_error_chunks*NATIVE_EVENT_CHUNKSIZE*sizeof(char *));
 		if (_papi_errlist==NULL) {
 			_papi_hwi_num_errors = -2;
@@ -604,9 +604,23 @@ PAPIERROR( char *format, ... )
 	if ( ( _papi_hwi_error_level != PAPI_QUIET ) ||
 		 ( getenv( "PAPI_VERBOSE" ) ) ) {
 		va_start( args, format );
-		fprintf( stderr, "\nPAPI Error: " );
+		fprintf( stderr, "PAPI Error: " );
 		vfprintf( stderr, format, args );
-		fprintf( stderr, ".\n" );
+		fprintf( stderr, "\n" );
+		va_end( args );
+	}
+}
+
+void
+PAPIWARN( char *format, ... )
+{
+	va_list args;
+	if ( ( _papi_hwi_error_level != PAPI_QUIET ) ||
+		 ( getenv( "PAPI_VERBOSE" ) ) ) {
+		va_start( args, format );
+		fprintf( stderr, "PAPI Warning: " );
+		vfprintf( stderr, format, args );
+		fprintf( stderr, "\n" );
 		va_end( args );
 	}
 }
@@ -2398,7 +2412,7 @@ _papi_hwi_query_native_event( unsigned int EventCode )
    Returns code = 0 and PAPI_OK if name not found.
    This allows for sparse native event arrays */
 int
-_papi_hwi_native_name_to_code( char *in, int *out )
+_papi_hwi_native_name_to_code( const char *in, int *out )
 {
     INTDBG("ENTER: in: %s, out: %p\n", in, out);
 
