@@ -1,15 +1,14 @@
 #!/bin/sh
-# $Id: install.sh,v 1.1.2.2 2007/04/09 12:50:36 mikpe Exp $
-# usage: etc/install.sh PREFIX BINDIR LIBDIR INCLDIR ETCDIR ARCH
+# $Id: install.sh,v 1.2 2005/01/16 22:44:34 mikpe Exp $
+# usage: etc/install.sh PREFIX BINDIR LIBDIR INCLDIR ARCH
 # If unset, {BIN,LIB,INCL}DIR are given default values from PREFIX.
-# Then make install2 is invoked with the final {BIN,LIB,INCL,ETC}DIR.
+# Then make install2 is invoked with the final {BIN,LIB,INCL}DIR.
 
 PREFIX=$1
 BINDIR=$2
 LIBDIR=$3
 INCLDIR=$4
-ETCDIR=$5
-ARCH=$6
+ARCH=$5
 
 case "$ARCH" in
   x86_64)
@@ -34,4 +33,4 @@ fix_var "$BINDIR" BINDIR bin
 fix_var "$LIBDIR" LIBDIR $LIBSUFFIX
 fix_var "$INCLDIR" INCLDIR include
 
-exec make "BINDIR=$BINDIR" "LIBDIR=$LIBDIR" "INCLDIR=$INCLDIR" "ETCDIR=$ETCDIR" install2
+exec make "BINDIR=$BINDIR" "LIBDIR=$LIBDIR" "INCLDIR=$INCLDIR" install2
